@@ -23,7 +23,9 @@
 #include "applet-struct.h"
 #include "applet-clipboard.h"
 
-const gchar *cEnvName[4] = {NULL, "gnome", "kde", "xfce"};
+const gchar *cEnvName[4] = {"other", "gnome", "kde", "xfce"};  // "other" allows to handle all the other DE (put your own actions into the corresponding file).
+
+// TODO idea: cairo_dock_cut_string => g_strstrip + cut X first char, then add '...', then the X last char + removed '\n'
 
 static int _cd_clipper_compare_item (CDClipperItem *pItem1, CDClipperItem *pItem2)
 {
@@ -35,7 +37,7 @@ static int _cd_clipper_compare_item (CDClipperItem *pItem1, CDClipperItem *pItem
 		return 0;
 }
 
-static GList *_cd_clipper_get_last_item (CDClipperItemType iItemType)
+GList *cd_clipper_get_last_item (CDClipperItemType iItemType)
 {
 	CDClipperItem *pItem = NULL;
 	GList *pElement;
@@ -102,8 +104,8 @@ void _on_text_received (GtkClipboard *pClipBoard, const gchar *text, gpointer us
 		pItem = myData.pItems->data;
 		if (pItem->iType & CD_CLIPPER_PRIMARY)  // le dernier item est aussi une selection souris
 		{
-			int len = strlen (pItem->cText);
-			if (len < strlen (text) && strncmp (pItem->cText, text, len) == 0)  // on ne peut pas dire len == strlen (text) - 1 avec l'UTF-8.
+			guint len = strlen (pItem->cText);
+			if (len < strlen (text) && (strncmp (pItem->cText, text, len) == 0 || strncmp (pItem->cText, text+strlen(text)-len, len) == 0))  // on ne peut pas dire len == strlen (text) - 1 avec l'UTF-8.
 			{
 				cd_debug ("incremental selection, drop previous one");
 				cd_clipper_free_item (pItem);
@@ -136,10 +138,10 @@ void _on_text_received (GtkClipboard *pClipBoard, const gchar *text, gpointer us
 		myData.pItems = g_list_delete_link (myData.pItems, pElement);
 		myData.iNbItems[pItem->iType] --;
 		
-		if (pItem->iType != iType && myData.iNbItems[iType] == myConfig.iNbItems[iType])
+		if (pItem->iType != iType && myData.iNbItems[iType] >= myConfig.iNbItems[iType])
 		{
 			cd_debug ("Clipper : %s remplace le dernier de l'autre selection", text);
-			pElement = _cd_clipper_get_last_item (iType);
+			pElement = cd_clipper_get_last_item (iType);
 			CD_APPLET_LEAVE_IF_FAIL (pElement != NULL);
 			cd_clipper_free_item (pElement->data);
 			myData.pItems = g_list_delete_link (myData.pItems, pElement);
@@ -152,10 +154,10 @@ void _on_text_received (GtkClipboard *pClipBoard, const gchar *text, gpointer us
 	{
 		bExistingItem = FALSE;
 		cd_debug ("%d items / %d", myData.iNbItems[iType], myConfig.iNbItems[iType]);
-		if (myData.iNbItems[iType] == myConfig.iNbItems[iType])
+		if (myData.iNbItems[iType] >= myConfig.iNbItems[iType])
 		{
 			cd_debug ("Clipper : %s remplace le dernier", text);
-			pElement = _cd_clipper_get_last_item (iType);
+			pElement = cd_clipper_get_last_item (iType);
 			CD_APPLET_LEAVE_IF_FAIL (pElement != NULL);
 			cd_clipper_free_item (pElement->data);
 			myData.pItems = g_list_delete_link (myData.pItems, pElement);
@@ -168,7 +170,7 @@ void _on_text_received (GtkClipboard *pClipBoard, const gchar *text, gpointer us
 		pItem = g_new0 (CDClipperItem, 1);
 		pItem->iType = iType;
 		pItem->cText = g_strdup (text);
-		pItem->cDisplayedText = cairo_dock_cut_string (text, 50);
+		pItem->cDisplayedText = cairo_dock_cut_string (g_strstrip (g_strdup (text)), 50); // g_strstrip: Removes leading and trailing whitespace from a string
 	}
 	myData.pItems = g_list_insert_sorted (myData.pItems, pItem, (GCompareFunc)_cd_clipper_compare_item);
 	myData.iNbItems[pItem->iType] ++;
@@ -379,7 +381,7 @@ static gboolean _cd_clipper_auto_destroy_action_menu (GtkWidget *pMenu)
 	CD_APPLET_ENTER;
 	if (pMenu == myData.pActionMenu)
 	{
-		g_print ("auto-destruction\n");
+		cd_debug ("auto-destruction\n");
 		gtk_widget_destroy (myData.pActionMenu);  // n'appellera pas le 'delete_menu'
 		myData.pActionMenu = NULL;
 	}
@@ -451,6 +453,9 @@ GtkWidget *cd_clipper_build_action_menu (CDClipperAction *pAction)
 			pImage = gtk_image_new_from_pixbuf (pixbuf);
 			g_free (cIconFilePath);
 			g_object_unref (pixbuf);
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+			gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (pMenuItem), TRUE);
+#endif
 			gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), pImage);
 		}
 		gtk_menu_shell_append  (GTK_MENU_SHELL (pMenu), pMenuItem);
@@ -590,7 +595,7 @@ void cd_clipper_popup_menu (GtkWidget *pMenu)
 		gtk_get_current_event_time ());
 }
 
-gchar *cd_clipper_concat_items_of_type (CDClipperItemType iType)
+gchar *cd_clipper_concat_items_of_type (CDClipperItemType iType, const gchar *cSeparator)
 {
 	GString *sText = g_string_new ("");
 	CDClipperItem *pItem;
@@ -600,9 +605,30 @@ gchar *cd_clipper_concat_items_of_type (CDClipperItemType iType)
 		pItem = it->data;
 		if ((pItem->iType & iType) == 0)
 			continue;
-		g_string_append_printf (sText, "%s\n", pItem->cText);
+		g_string_append_printf (sText, "%s%s", pItem->cText, it->next ? cSeparator : "");
 	}
 	gchar *cText = sText->str;
 	g_string_free (sText, FALSE);
 	return cText;
 }
+
+void cd_clipper_load_items (const gchar *cItems)
+{
+	CDClipperItem *pItem;
+	int iClipperItemType = myConfig.bSeparateSelections ? CD_CLIPPER_CLIPBOARD : CD_CLIPPER_BOTH;
+	gchar **cItemList = g_strsplit (cItems, CD_ITEMS_DELIMITER, -1);
+	int i;
+	for (i = 0; cItemList[i] != NULL; i ++)
+	{
+		// if we have reduced the number of items to display
+		if (i == myConfig.iNbItems[iClipperItemType])
+			break;
+		pItem = g_new0 (CDClipperItem, 1);
+		pItem->iType = iClipperItemType;
+		pItem->cText = cItemList[i];
+		pItem->cDisplayedText = cairo_dock_cut_string (g_strstrip (pItem->cText), 50); // g_strstrip: Removes leading and trailing whitespace from a string
+		myData.pItems = g_list_insert_sorted (myData.pItems, pItem, (GCompareFunc)_cd_clipper_compare_item);
+		myData.iNbItems[iClipperItemType] ++;
+	}
+	g_free (cItemList);
+}
