@@ -55,7 +55,7 @@ static void on_click_category_button (GtkButton *button, gpointer data)
 	if (! gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (button)))
 		return;
 	myData.iCurrentCaterogy = GPOINTER_TO_INT (data);
-	g_print ("filter on category %d\n", myData.iCurrentCaterogy);
+	cd_debug ("filter on category %d", myData.iCurrentCaterogy);
 	cd_trigger_search ();
 }
 
@@ -63,7 +63,7 @@ static void on_click_category_button (GtkButton *button, gpointer data)
 static void on_clear_filter (GtkEntry *pEntry, GtkEntryIconPosition icon_pos, GdkEvent *event, gpointer data)
 {
 	gtk_entry_set_text (pEntry, "");
-	g_print ("relaunch the search...\n");
+	cd_debug ("relaunch the search...");
 	cd_trigger_search ();
 }
 #endif
@@ -81,13 +81,13 @@ static void _on_got_events (ZeitgeistResultSet *pEvents, GtkListStore *pModel)
 	gint64 iTimeStamp;
 	const gchar *cEventURI;
 	guint id;
-	gchar *cName = NULL, *cURI = NULL, *cIconName = NULL, *cPath = NULL;
+	gchar *cName = NULL, *cURI = NULL, *cIconName = NULL, *cIconPath, *cPath = NULL;
 	double fOrder;
 	int iVolumeID;
 	gboolean bIsDirectory;
 	GdkPixbuf *pixbuf;
 	GtkTreeIter iter;
-	GHashTable *pHashTable = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
+	GHashTable *pHashTable = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);  // used to prevent doubles
 	
 	//\_____________ parse all the events.
 	while (zeitgeist_result_set_has_next (pEvents))
@@ -97,7 +97,7 @@ static void _on_got_events (ZeitgeistResultSet *pEvents, GtkListStore *pModel)
 		id = zeitgeist_event_get_id (event);
 		n = zeitgeist_event_num_subjects (event);
 		if (n > 1)
-			g_print (" +++ %s, %s, %d\n", zeitgeist_event_get_interpretation (event), zeitgeist_event_get_manifestation (event), n);
+			cd_debug (" +++ %s, %s, %d", zeitgeist_event_get_interpretation (event), zeitgeist_event_get_manifestation (event), n);
 		for (i = 0; i < n; i++)
 		{
 			subject = zeitgeist_event_get_subject (event, i);
@@ -121,11 +121,13 @@ static void _on_got_events (ZeitgeistResultSet *pEvents, GtkListStore *pModel)
 			else
 			{
 				cairo_dock_fm_get_file_info (cEventURI, &cName, &cURI, &cIconName, &bIsDirectory, &iVolumeID, &fOrder, CAIRO_DOCK_FM_SORT_BY_DATE);
-				g_free (cName);
-				g_free (cURI);
 			}
 			if (cIconName != NULL)
-				pixbuf = gdk_pixbuf_new_from_file_at_size (cIconName, 32, 32, NULL);
+			{
+				cIconPath = cairo_dock_search_icon_s_path (cIconName);
+				pixbuf = gdk_pixbuf_new_from_file_at_size (cIconPath, 32, 32, NULL);
+				g_free (cIconPath);
+			}
 			else
 				pixbuf = NULL;
 			
@@ -166,7 +168,13 @@ static void _on_got_events (ZeitgeistResultSet *pEvents, GtkListStore *pModel)
 				CD_MODEL_ICON, pixbuf,
 				CD_MODEL_DATE, iTimeStamp,
 				CD_MODEL_ID, id, -1);
+			
 			g_free (cIconName);
+			cIconName = NULL;
+			g_free (cName);
+			cName = NULL;
+			g_free (cURI);
+			cURI = NULL;
 			if (pixbuf)
 				g_object_unref (pixbuf);
 			g_free (cPath);
@@ -222,7 +230,7 @@ static gboolean _on_click_module_tree_view (GtkTreeView *pTreeView, GdkEventButt
 	if ((pButton->button == 3 && pButton->type == GDK_BUTTON_RELEASE)  // right-click
 	|| (pButton->button == 1 && pButton->type == GDK_2BUTTON_PRESS))  // double-click
 	{
-		g_print ("%s ()\n", __func__);
+		cd_debug ("%s ()", __func__);
 		// get the current selected line.
 		GtkTreeSelection *pSelection = gtk_tree_view_get_selection (pTreeView);
 		GtkTreeModel *pModel;
@@ -354,7 +362,7 @@ static GtkWidget *cd_build_events_widget (void)
 	gtk_box_pack_start (GTK_BOX (pMainBox), pToolBar, TRUE, TRUE, MARGIN);
 	
 	int i = 0;
-	GtkToolItem *group = _add_category_button (pToolBar, D_("All"), "stock_all", i++, NULL);
+	GtkToolItem *group = _add_category_button (pToolBar, D_("All"), "stock_search", i++, NULL);
 	_add_category_button (pToolBar, D_("Document"), "document", i++, group);
 	///_add_category_button (pToolBar, D_("Folder"), "folder", i++, group);
 	_add_category_button (pToolBar, D_("Image"), "image", i++, group);
@@ -369,6 +377,7 @@ static GtkWidget *cd_build_events_widget (void)
 	gtk_box_pack_start (GTK_BOX (pMainBox), pFilterBox, FALSE, FALSE, MARGIN);
 	
 	GtkWidget *pFilterLabel = gtk_label_new (D_("Look for events"));
+	cairo_dock_set_dialog_widget_text_color (GTK_WIDGET (pFilterLabel));
 	gtk_box_pack_start (GTK_BOX (pFilterBox), pFilterLabel, FALSE, FALSE, MARGIN);
 	
 	GtkWidget *pEntry = gtk_entry_new ();
@@ -442,37 +451,60 @@ static GtkWidget *cd_build_events_widget (void)
 	return pMainBox;
 }
 
-static gboolean on_button_press_dialog (GtkWidget *widget, GdkEventButton *pButton, CairoDockModuleInstance *myApplet)
-{
-	CD_APPLET_ENTER;
-	cairo_dock_dialog_unreference (myData.pDialog);
-	myData.pDialog = NULL;
-	CD_APPLET_LEAVE(FALSE);
-}
-static void _on_dialog_destroyed (gpointer data)
+static void _on_dialog_destroyed (CairoDockModuleInstance *myApplet)
 {
 	myData.pDialog = NULL;
-	myData.pEntry = NULL;
+	myData.pEntry = NULL;  // interactive widget inside the dialog are destroyed with it.
 	myData.iCurrentCaterogy = CD_EVENT_ALL;
 	myData.pModel = NULL;	
 }
+static gboolean _show_dialog_delayed (gpointer data)
+{
+	cd_toggle_dialog ();
+	return FALSE;
+}
 void cd_toggle_dialog (void)
 {
-	if (myData.pDialog != NULL)
+	if (myData.pDialog != NULL)  // the dialog can be opened in the case it was called from the shortkey.
 	{
 		cairo_dock_dialog_unreference (myData.pDialog);
 		myData.pDialog = NULL;
 	}
 	else
 	{
-		GtkWidget *pInteractiveWidget = cd_build_events_widget ();
-		myData.pDialog = cairo_dock_show_dialog_full (D_("Browse and search in recent events"), myIcon, myContainer, 0, "same icon", pInteractiveWidget, NULL, myApplet, (GFreeFunc) _on_dialog_destroyed);
-		gtk_widget_grab_focus (myData.pEntry);
-		g_signal_connect (G_OBJECT (myData.pDialog->container.pWidget),
-			"button-press-event",
-			G_CALLBACK (on_button_press_dialog),
-			myApplet);
+		// establish the connection to Zeitgesit.
+		if (myData.pLog == NULL)  // first search.
+		{
+			cd_debug ("first search");
+			myData.pLog = zeitgeist_log_new ();  // may launch the Zeitgeist daemon if it's not yet running.
+			if (! zeitgeist_log_is_connected (myData.pLog))  // the connection may not be immediate (even if the daemon is already running), in this case come back in 1s.
+			{
+				cd_debug ("come back in 1s...");
+				g_timeout_add_seconds (1, _show_dialog_delayed, NULL);
+				return;
+			}
+		}
+		else if (! zeitgeist_log_is_connected (myData.pLog))
+		{
+			cairo_dock_remove_dialog_if_any (myIcon);
+			cairo_dock_show_temporary_dialog_with_icon (D_("You need to install the Zeitgeist data engine."), myIcon, myContainer, 6000, "same icon");
+			return;
+		}
 		
+		// build the dialog and the tree model.
+		GtkWidget *pInteractiveWidget = cd_build_events_widget ();
+		myData.pDialog = cairo_dock_show_dialog_full (D_("Browse and search in recent events"),
+			myIcon,
+			myContainer,
+			0,
+			"same icon",
+			pInteractiveWidget,
+			NULL,
+			myApplet,
+			(GFreeFunc) _on_dialog_destroyed);
+		gtk_widget_grab_focus (myData.pEntry);
+		
+		// trigger the search that will fill the model.
 		cd_trigger_search ();
 	}
 }
