@@ -41,14 +41,13 @@ static inline double _percent_to_gamma (double fGammaPercent)
 	return GAMMA_MIN + fGammaPercent / 100. * (GAMMA_MAX - GAMMA_MIN);
 }
 
-void xgamma_add_gamma (XF86VidModeGamma *pGamma, gboolean bAdd)
+void xgamma_add_gamma (XF86VidModeGamma *pGamma, gint iNbSteps)
 {
+	if (iNbSteps == 0)
+		return;
 	double fGamma = xgamma_get_gamma (pGamma);
 	double fGammaPercent = _gamma_to_percent (fGamma);
-	if (bAdd)
-		fGammaPercent += myConfig.iScrollVariation;
-	else
-		fGammaPercent -= myConfig.iScrollVariation;
+	fGammaPercent += iNbSteps * myConfig.iScrollVariation;
 	double fNewGamma = _percent_to_gamma (fGammaPercent);
 	double f = fNewGamma / fGamma;
 	myData.Xgamma.red *= f;
@@ -85,14 +84,10 @@ void xgamma_set_gamma (XF86VidModeGamma *pGamma)
 	}
 	else
 	{
-		double fGamma = (pGamma->red + pGamma->blue + pGamma->green) / 3;
-		double fGammaPercent = _gamma_to_percent (fGamma);
-		
 		if (myConfig.cDefaultTitle == NULL)
 		{
-			gchar *cLabel = g_strdup_printf ("Luminosity: %d%%", (int)fGammaPercent);
-			cairo_dock_set_icon_name (cLabel, myIcon, myContainer);
-			g_free (cLabel);
+			double fGamma = (pGamma->red + pGamma->blue + pGamma->green) / 3;
+			cd_gamma_display_gamma_on_label (fGamma);
 		}
 	}
 }
@@ -280,3 +275,12 @@ CairoDialog *xgamma_build_dialog_simple (void)
 	attr.pUserData = myApplet;
 	return cairo_dock_build_dialog (&attr, myIcon, myContainer);
 }
+
+
+void cd_gamma_display_gamma_on_label (double fGamma)
+{
+	double fGammaPercent = _gamma_to_percent (fGamma);
+	gchar *cLabel = g_strdup_printf ("%s: %d%%", D_("Luminosity"), (int)fGammaPercent);
+	cairo_dock_set_icon_name (cLabel, myIcon, myContainer);
+	g_free (cLabel);
+}
