@@ -81,10 +81,6 @@ static inline void _get_gridXY_from_index (guint nRowsX, guint index, guint* gri
 	*gridX = index % nRowsX;
 	*gridY = index / nRowsX;
 }
-static inline guint _get_index_from_gridXY (guint nRowsX, guint gridX, guint gridY)
-{
-	return gridX + gridY * nRowsX;
-}
 
 static guint _cd_rendering_diapo_simple_guess_grid (GList *pIconList, guint *nRowX, guint *nRowY)
 {
@@ -325,8 +321,8 @@ static void cd_rendering_calculate_max_dock_size_diapo_simple (CairoDock *pDock)
 	}
 	else
 	{
-		iDockWidth = X_BORDER_SPACE * 2 + 1;
-		iDockHeight = my_diapo_simple_lineWidth + my_diapo_simple_arrowHeight + ARROW_TIP + 1;
+		iDockWidth = X_BORDER_SPACE * 2 + my_diapo_simple_arrowWidth + 10;
+		iDockHeight = my_diapo_simple_lineWidth + my_diapo_simple_arrowHeight + ARROW_TIP + 10;
 	}
 	
 	CDSlideData *pData = pDock->pRendererData;
@@ -376,6 +372,9 @@ static void cd_rendering_calculate_max_dock_size_diapo_simple (CairoDock *pDock)
 	// On affecte ca aussi au cas ou.
 	pDock->fFlatDockWidth = pDock->iMaxDockWidth;
 	pDock->fMagnitudeMax = my_diapo_simple_fScaleMax / (1+myIconsParam.fAmplitude);
+	
+	pDock->iActiveWidth = pDock->iMaxDockWidth;
+	pDock->iActiveHeight = pDock->iMaxDockHeight;
 }
 
 
@@ -817,12 +816,13 @@ static Icon* _cd_rendering_calculate_icons_for_diapo_simple (CairoDock *pDock, g
 	int iOffsetY;
 	if (pDock->container.bDirectionUp)
 		iOffsetY = .5 * pDock->iMaxIconHeight * pDock->container.fRatio * (my_diapo_simple_fScaleMax - 1) +  // les icones de la 1ere ligne zooment
-			myIconsParam.iLabelSize +  // le texte des icones de la 1ere ligne
+			(pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : .5*myIconsParam.iLabelSize) +  // le texte des icones de la 1ere ligne
 			.5 * my_diapo_simple_lineWidth +  // demi-ligne du haut;
 			fScrollOffset;
 	else
 		iOffsetY = .5 * pDock->iMaxIconHeight * pDock->container.fRatio * (my_diapo_simple_fScaleMax - 1) +  // les icones de la 1ere ligne zooment
 				.5 * my_diapo_simple_lineWidth +  // demi-ligne du bas;
+				(pDock->container.bIsHorizontal ? 0 : myIconsParam.iLabelSize/2) +
 				fScrollOffset;
 	double fFoldingX = (pDock->fFoldingFactor > .2 ? (pDock->fFoldingFactor - .2) / .8 : 0.);  // placement de 1 a 0.2
 	double fFoldingY = (pDock->fFoldingFactor > .5 ? (pDock->fFoldingFactor - .5) / .5 : 0.);  // placement de 1 a 0.5
@@ -911,9 +911,85 @@ static void _cd_rendering_check_if_mouse_inside_diapo_simple (CairoDock *pDock)
 		pDock->iMousePositionType = CAIRO_DOCK_MOUSE_INSIDE;
 	}
 }
-static void _cd_rendering_check_can_drop_linear (CairoDock *pDock)
+#define make_icon_avoid_mouse(icon, sens) do { \
+	cairo_dock_mark_icon_as_avoiding_mouse (icon);\
+	icon->fAlpha = 0.75;\
+	if (myIconsParam.fAmplitude != 0)\
+		icon->fDrawX += icon->fWidth / 2 * (icon->fScale - 1) / myIconsParam.fAmplitude * sens; } while (0)
+///TODO: make it work...
+static inline gboolean _check_can_drop (CairoDock *pDock, CairoDockIconGroup iGroup, double fMargin)
 {
-	pDock->bCanDrop = pDock->bIsDragging;  /// calculer bCanDrop ...
+	gboolean bUndefined = TRUE;
+	gboolean bCanDrop = FALSE;
+	Icon *icon;
+	GList *ic;
+	for (ic = pDock->icons; ic != NULL; ic = ic->next)
+	{
+		icon = ic->data;
+		if (icon->bPointed)
+		{
+			if (pDock->container.iMouseX < icon->fDrawX + icon->fWidth * icon->fScale * fMargin)  // on est a gauche.  // fDrawXAtRest
+			{
+				GList *prev_ic = ic->prev;
+				Icon *prev_icon = (prev_ic ? prev_ic->data : NULL);
+				if (cairo_dock_get_icon_order (icon) == cairo_dock_get_group_order (iGroup)
+				|| (prev_icon && cairo_dock_get_icon_order (prev_icon) == cairo_dock_get_group_order (iGroup)) )
+				{
+					make_icon_avoid_mouse (icon, 1);
+					if (prev_icon)
+						make_icon_avoid_mouse (prev_icon, -1);
+					//g_print ("%s> <%s\n", prev_icon->cName, icon->cName);
+					bCanDrop = TRUE;
+					bUndefined = FALSE;
+				}
+			}
+			else if (pDock->container.iMouseX > icon->fDrawX + icon->fWidth * icon->fScale * (1 - fMargin))  // on est a droite.  // fDrawXAtRest
+			{
+				GList *next_ic = ic->next;
+				Icon *next_icon = (next_ic ? next_ic->data : NULL);
+				if (cairo_dock_get_icon_order (icon) == cairo_dock_get_group_order (iGroup)
+				|| (next_icon && cairo_dock_get_icon_order (next_icon) == cairo_dock_get_group_order (iGroup)) )
+				{
+					make_icon_avoid_mouse (icon, -1);
+					if (next_icon)
+						make_icon_avoid_mouse (next_icon, 1);
+					bCanDrop = TRUE;
+					bUndefined = FALSE;
+				}
+				ic = ic->next;  // on la saute pour ne pas la de-marquer.
+				if (ic == NULL)
+					break;
+			}
+			else  // on the icon
+			{
+				bCanDrop = FALSE;
+				bUndefined = FALSE;
+			}
+		}
+		else
+			cairo_dock_stop_marking_icon_as_avoiding_mouse (icon);
+	}
+	
+	if (bUndefined)  // no pointed icon, so we are either on the side, on between icons.
+	{
+		bCanDrop = (pDock->container.iMouseX > X_BORDER_SPACE && pDock->container.iMouseX < pDock->container.iWidth - X_BORDER_SPACE);  // no drop on the side.
+	}
+	return bCanDrop;
+}
+static void _cd_rendering_check_can_drop (CairoDock *pDock)
+{
+	if (! pDock->bIsDragging)  // not dragging, so no drop possible.
+	{
+		pDock->bCanDrop = FALSE;
+	}
+	else if (pDock->icons == NULL)  // dragging but no icons, so drop always possible.
+	{
+		pDock->bCanDrop = TRUE;
+	}
+	else  // dragging and some icons.
+	{
+		pDock->bCanDrop = _check_can_drop (pDock, pDock->iAvoidingMouseIconType, pDock->fAvoidingMouseMargin);
+	}
 }
 Icon *cd_rendering_calculate_icons_diapo_simple (CairoDock *pDock)
 {
@@ -925,13 +1001,15 @@ Icon *cd_rendering_calculate_icons_diapo_simple (CairoDock *pDock)
 	// On recupere la configuration de la grille
 	gint nRowsX = pData->nRowsX;
 	gint nRowsY = pData->nRowsY;
+	if (nRowsX == 0 || nRowsY == 0)  // maybe a dock with no displayed icons (like 1 separator); anyway the grid is not valid, so discard.
+		return NULL;
 	
 	// On calcule les parametres des icones
 	Icon *pPointedIcon = _cd_rendering_calculate_icons_for_diapo_simple (pDock, nRowsX, nRowsY, pDock->container.iMouseX, pDock->container.iMouseY);
 	
 	_cd_rendering_check_if_mouse_inside_diapo_simple (pDock);
 	
-	_cd_rendering_check_can_drop_linear (pDock);
+	_cd_rendering_check_can_drop (pDock);
 	
 	return pPointedIcon;
 }
@@ -1406,12 +1484,12 @@ void cd_rendering_set_subdock_position_slide (Icon *pPointedIcon, CairoDock *pDo
 	{
 		pSubDock->fAlign = 0.5;
 		pSubDock->iGapX = iX + pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] / 2;  // ici les sous-dock ont un alignement egal a 0.5
-		pSubDock->iGapY = pDock->iGapY + pDock->iMaxDockHeight;
+		pSubDock->iGapY = pDock->iGapY + pDock->iActiveHeight;
 	}
 	else
 	{
 		pSubDock->fAlign = (pDock->container.bDirectionUp ? 1 : 0);
-		pSubDock->iGapX = (pDock->iGapY + pDock->iMaxDockHeight) * (pDock->container.bDirectionUp ? -1 : 1);
+		pSubDock->iGapX = (pDock->iGapY + pDock->iActiveHeight) * (pDock->container.bDirectionUp ? -1 : 1);
 		if (pDock->container.bDirectionUp)
 			pSubDock->iGapY = g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - (iX + pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY)) - pSubDock->iMaxDockHeight / 2;  // les sous-dock ont un alignement egal a 1.
 		else
