@@ -235,7 +235,7 @@ void vfs_backend_get_file_info (const gchar *cBaseURI, gchar **cName, gchar **cU
 
 
 
-GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iSortType, int iNewIconsType, gboolean bListHiddenFiles, gchar **cFullURI)
+GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iSortType, int iNewIconsType, gboolean bListHiddenFiles, int iNbMaxFiles, gchar **cFullURI)
 {
 	g_return_val_if_fail (cBaseURI != NULL, NULL);
 	cd_message ("%s (%s)", __func__, cBaseURI);
@@ -267,9 +267,10 @@ GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iS
 	cd_message ("  dirUri : %s", dirUri->text);
 	GnomeVFSURI* fileUri;
 	gchar *cFileURI;
+	int iNbFiles = 0;
 	GnomeIconLookupResultFlags iconLookupResultFlags;
 	Icon *icon;
-	while(1)
+	while(iNbFiles < iNbMaxFiles)
 	{
 		r = gnome_vfs_directory_read_next (handle, info);
 		if (r == GNOME_VFS_ERROR_EOF)
@@ -296,9 +297,9 @@ GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iS
 				}
 			}
 			
-			icon = g_new0 (Icon, 1);
+			icon = cairo_dock_create_dummy_launcher (NULL, NULL, NULL, NULL, 0);
 			icon->cBaseURI = cFileURI;
-			icon->iType = iNewIconsType;
+			icon->iGroup = iNewIconsType;
 			if ( (valid & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE) && strcmp (info->mime_type, "application/x-desktop") == 0)
 			{
 				gboolean bIsDirectory = FALSE;
@@ -346,6 +347,7 @@ GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iS
 			else if (iSortType == CAIRO_DOCK_FM_SORT_BY_TYPE && (valid & GNOME_VFS_FILE_INFO_FIELDS_TYPE))
 				icon->fOrder = info->type;
 			pIconList = g_list_prepend (pIconList, icon);
+			iNbFiles ++;
 			
 			gnome_vfs_uri_unref (fileUri);
 		}
@@ -412,7 +414,7 @@ static void _vfs_backend_mount_callback (gboolean succeeded, char *error, char *
 	g_free (data);
 }
 
-void vfs_backend_mount (const gchar *cURI, int iVolumeID, CairoDockFMMountCallback pCallback, Icon *icon, CairoContainer *pContainer)
+void vfs_backend_mount (const gchar *cURI, int iVolumeID, CairoDockFMMountCallback pCallback, gpointer user_data)
 {
 	g_return_if_fail (iVolumeID > 0);
 	cd_message ("%s (ID:%d)", __func__, iVolumeID);
@@ -432,15 +434,15 @@ void vfs_backend_mount (const gchar *cURI, int iVolumeID, CairoDockFMMountCallba
 	data2[0] = pCallback;
 	data2[1] = GINT_TO_POINTER (TRUE);
 	data2[2] = gnome_vfs_drive_get_display_name (pDrive);
-	data2[3] = icon;
-	data2[4] = pContainer;
+	data2[3] = g_strdup (cURI);
+	data2[4] = user_data;
 	gnome_vfs_drive_mount (pDrive, (GnomeVFSVolumeOpCallback)_vfs_backend_mount_callback, data2);
 	
 	///gnome_vfs_volume_unref (pVolume);
 	gnome_vfs_drive_unref (pDrive);
 }
 
-void vfs_backend_unmount (const gchar *cURI, int iVolumeID, CairoDockFMMountCallback pCallback, Icon *icon, CairoContainer *pContainer)
+void vfs_backend_unmount (const gchar *cURI, int iVolumeID, CairoDockFMMountCallback pCallback, gpointer user_data)
 {
 	g_return_if_fail (cURI != NULL);
 	cd_message ("%s (%s)", __func__, cURI);
@@ -456,8 +458,8 @@ void vfs_backend_unmount (const gchar *cURI, int iVolumeID, CairoDockFMMountCall
 	data2[0] = pCallback;
 	data2[1] = GINT_TO_POINTER (FALSE);
 	data2[2] = gnome_vfs_volume_get_display_name (pVolume);
-	data2[3] = icon;
-	data2[4] = pContainer;
+	data2[3] = g_strdup (cURI);
+	data2[4] = user_data;
 	gnome_vfs_volume_unmount (pVolume, (GnomeVFSVolumeOpCallback)_vfs_backend_mount_callback, data2);
 	
 	gnome_vfs_volume_unref (pVolume);
