@@ -91,7 +91,14 @@ static gchar *_cd_get_icon_path (GIcon *pIcon, const gchar *cTargetURI)  // cTar
 		for (i = 0; cFileNames[i] != NULL && cIconPath == NULL; i ++)
 		{
 			//g_print (" une icone possible est : %s\n", cFileNames[i]);
-			cIconPath = cairo_dock_search_icon_s_path (cFileNames[i]);
+			
+			gchar *path = cairo_dock_search_icon_s_path (cFileNames[i]);
+			if (path)
+			{
+				g_free (path);
+				cIconPath = g_strdup (cFileNames[i]);
+			}
+			
 			//g_print ("  chemin trouve : %s\n", cIconPath);
 		}
 	}
@@ -136,7 +143,7 @@ static void _cd_find_mount_from_volume_name (const gchar *cVolumeName, GMount **
 		&erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome_integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_error_free (erreur);
 		g_object_unref (pFile);
 		return ;
@@ -150,7 +157,7 @@ static void _cd_find_mount_from_volume_name (const gchar *cVolumeName, GMount **
 		pFileInfo = g_file_enumerator_next_file (pFileEnum, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			erreur = NULL;
 		}
@@ -311,7 +318,7 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 		cValidUri = g_filename_from_uri (cNautilusFile, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			return ;
 		}
@@ -319,13 +326,26 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 		cd_message ("cVolumeName : %s", cVolumeName);
 		
 		GMount *pMount = NULL;
-		_cd_find_mount_from_volume_name (cVolumeName, &pMount, cURI, cIconName);
+		gchar *uri=NULL, *iconname=NULL;
+		_cd_find_mount_from_volume_name (cVolumeName, &pMount, &uri, &iconname);
 		g_return_if_fail (pMount != NULL);
 		
-		*cName = g_strdup (cVolumeName);
-		*bIsDirectory = TRUE;
-		*iVolumeID = 1;
-		*fOrder = 0;
+		if (cURI)
+			*cURI = uri;
+		else
+			g_free (uri);
+		if (cIconName)
+			*cIconName = iconname;
+		else
+			g_free (iconname);
+		if (cName)
+			*cName = g_strdup (cVolumeName);
+		if (bIsDirectory)
+			*bIsDirectory = TRUE;
+		if (iVolumeID)
+			*iVolumeID = 1;
+		if (fOrder)
+			*fOrder = 0;
 		//g_object_unref (pMount);
 		
 		g_free (cValidUri);
@@ -367,10 +387,9 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 		G_FILE_QUERY_INFO_NONE,  /// G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS
 		NULL,
 		&erreur);
-	//g_object_unref (pFile);
 	if (erreur != NULL)  // peut arriver si l'emplacement n'est pas monte.
 	{
-		cd_debug ("gnome_integration : %s", erreur->message);  // inutile d'en faire un warning.
+		cd_debug ("gvfs-integration : %s", erreur->message);  // inutile d'en faire un warning.
 		g_error_free (erreur);
 		g_free (cValidUri);
 		g_object_unref (pFile);
@@ -380,135 +399,155 @@ static void cairo_dock_gio_vfs_get_file_info (const gchar *cBaseURI, gchar **cNa
 	const gchar *cFileName = g_file_info_get_name (pFileInfo);
 	const gchar *cMimeType = g_file_info_get_content_type (pFileInfo);
 	GFileType iFileType = g_file_info_get_file_type (pFileInfo);
-	
-	if (iSortType == CAIRO_DOCK_FM_SORT_BY_DATE)
-	{
-		GTimeVal t;
-		g_file_info_get_modification_time (pFileInfo, &t);
-		*fOrder = t.tv_sec;
-	}
-	else if (iSortType == CAIRO_DOCK_FM_SORT_BY_ACCESS)
-		*fOrder =  g_file_info_get_attribute_uint64 (pFileInfo, G_FILE_ATTRIBUTE_TIME_ACCESS);
-	else if (iSortType == CAIRO_DOCK_FM_SORT_BY_SIZE)
-		*fOrder = g_file_info_get_size (pFileInfo);
-	else if (iSortType == CAIRO_DOCK_FM_SORT_BY_TYPE)
-		*fOrder = (cMimeType != NULL ? *((int *) cMimeType) : 0);
-	else
-		*fOrder = 0;
-	
-	*bIsDirectory = (iFileType == G_FILE_TYPE_DIRECTORY);
-	cd_message (" => '%s' (mime:%s ; bIsDirectory:%d)", cFileName, cMimeType, *bIsDirectory);
-	
 	const gchar *cTargetURI = g_file_info_get_attribute_string (pFileInfo, G_FILE_ATTRIBUTE_STANDARD_TARGET_URI);
 	
-	// if it's a mount point, find a readable name.
+	// find the order of the file
+	if (fOrder)
+	{
+		if (iSortType == CAIRO_DOCK_FM_SORT_BY_DATE)
+		{
+			GTimeVal t;
+			g_file_info_get_modification_time (pFileInfo, &t);
+			*fOrder = t.tv_sec;
+		}
+		else if (iSortType == CAIRO_DOCK_FM_SORT_BY_ACCESS)
+			*fOrder =  g_file_info_get_attribute_uint64 (pFileInfo, G_FILE_ATTRIBUTE_TIME_ACCESS);
+		else if (iSortType == CAIRO_DOCK_FM_SORT_BY_SIZE)
+			*fOrder = g_file_info_get_size (pFileInfo);
+		else if (iSortType == CAIRO_DOCK_FM_SORT_BY_TYPE)
+			*fOrder = (cMimeType != NULL ? *((int *) cMimeType) : 0);
+		else
+			*fOrder = 0;
+	}
+	
+	if (bIsDirectory)
+		*bIsDirectory = (iFileType == G_FILE_TYPE_DIRECTORY);
+	
+	
+	// find a readable name if it's a mount point.
 	if (iFileType == G_FILE_TYPE_MOUNTABLE)
 	{
-		*cName = NULL;
-		*iVolumeID = 1;
+		if (iVolumeID)
+			*iVolumeID = 1;
 		
-		cd_message ("  cTargetURI:%s", cTargetURI);
-		GMount *pMount = NULL;
-		if (cTargetURI != NULL)
+		if (cName)
 		{
-			GFile *file = g_file_new_for_uri (cTargetURI);
-			pMount = g_file_find_enclosing_mount (file, NULL, NULL);
-			//g_object_unref (file);
-		}
-		if (pMount != NULL)
-		{
-			*cName = g_mount_get_name (pMount);
-			cd_message ("un GMount existe (%s)",* cName);
-		}
-		else
-		{
-			gchar *cMountName = g_strdup (cFileName);
-			gchar *str = strrchr (cMountName, '.');  // on vire l'extension ".volume" ou ".drive".
-			if (str != NULL)
+			*cName = NULL;
+			
+			cd_message ("  cTargetURI:%s", cTargetURI);
+			GMount *pMount = NULL;
+			if (cTargetURI != NULL)
 			{
-				*str = '\0';
-				if (strcmp (str+1, "link") == 0)  // pour les liens, on prend le nom du lien.
-				{
-					if (strcmp (cMountName, "root") == 0)  // on remplace 'root' par un nom plus parlant, sinon on prendra le nom du lien.
-					{
-						*cName = g_strdup ("/");
-					}
-				}
-				else if (strcmp (str+1, "drive") == 0)  // on cherche un nom plus parlant si possible.
-				{
-					gchar *cVolumeName = _cd_find_volume_name_from_drive_name (cMountName);
-					if (cVolumeName != NULL)
-					{
-						*cName = cVolumeName;
-					}
-				}
+				GFile *file = g_file_new_for_uri (cTargetURI);
+				pMount = g_file_find_enclosing_mount (file, NULL, NULL);
+				//g_object_unref (file);
 			}
-			if (*cName == NULL)
-				*cName = cMountName;
-			//else
-				//g_free (cMountName);
+			if (pMount != NULL)
+			{
+				*cName = g_mount_get_name (pMount);
+				cd_message ("un GMount existe (%s)",* cName);
+			}
+			else
+			{
+				gchar *cMountName = g_strdup (cFileName);
+				gchar *str = strrchr (cMountName, '.');  // on vire l'extension ".volume" ou ".drive".
+				if (str != NULL)
+				{
+					*str = '\0';
+					if (strcmp (str+1, "link") == 0)  // pour les liens, on prend le nom du lien.
+					{
+						if (strcmp (cMountName, "root") == 0)  // on remplace 'root' par un nom plus parlant, sinon on prendra le nom du lien.
+						{
+							*cName = g_strdup ("/");
+						}
+					}
+					else if (strcmp (str+1, "drive") == 0)  // on cherche un nom plus parlant si possible.
+					{
+						gchar *cVolumeName = _cd_find_volume_name_from_drive_name (cMountName);
+						if (cVolumeName != NULL)
+						{
+							*cName = cVolumeName;
+						}
+					}
+				}
+				if (*cName == NULL)
+					*cName = cMountName;
+				//else
+					//g_free (cMountName);
+			}
+			if (*cName ==  NULL)
+				*cName = g_strdup (cFileName);
 		}
-		if (*cName ==  NULL)
+	}
+	else  // for an normal file, just re-use the filename
+	{
+		if (iVolumeID)
+			*iVolumeID = 0;
+		if (cName)
 			*cName = g_strdup (cFileName);
 	}
-	else
-	{
-		*iVolumeID = 0;
-		*cName = g_strdup (cFileName);
-	}
 	
-	if (cTargetURI)
+	// find the target URI if it's a mount point
+	if (cURI)
 	{
-		*cURI = g_strdup (cTargetURI);
-		g_free (cValidUri);
-		cValidUri = NULL;
+		if (cTargetURI)
+		{
+			*cURI = g_strdup (cTargetURI);
+			g_free (cValidUri);
+			cValidUri = NULL;
+		}
+		else
+			*cURI = cValidUri;
 	}
-	else
-		*cURI = cValidUri;
 	
 	// find an icon.
-	*cIconName = NULL;
-	*cIconName = g_strdup (g_file_info_get_attribute_byte_string (pFileInfo, G_FILE_ATTRIBUTE_THUMBNAIL_PATH));
-	#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 20)
-	/**if (*cIconName == NULL)
+	if (cIconName)
 	{
-		GIcon *pPreviewIcon = (GIcon *)g_file_info_get_attribute_object (pFileInfo, G_FILE_ATTRIBUTE_PREVIEW_ICON);
-		if (pPreviewIcon != NULL)
+		*cIconName = NULL;
+		// first use an available thumbnail.
+		*cIconName = g_strdup (g_file_info_get_attribute_byte_string (pFileInfo, G_FILE_ATTRIBUTE_THUMBNAIL_PATH));
+		#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 20)
+		/**if (*cIconName == NULL)
 		{
-			*cIconName = _cd_get_icon_path (pPreviewIcon, NULL);
-			//g_print ("got preview icon '%s'\n", *cIconName);
-		}
-	}*/
-	#endif
-	if (*cIconName == NULL && cMimeType != NULL && strncmp (cMimeType, "image", 5) == 0)
-	{
-		gchar *cHostname = NULL;
-		GError *erreur = NULL;
-		gchar *cFilePath = g_filename_from_uri (cBaseURI, &cHostname, &erreur);
-		if (erreur != NULL)
+			GIcon *pPreviewIcon = (GIcon *)g_file_info_get_attribute_object (pFileInfo, G_FILE_ATTRIBUTE_PREVIEW_ICON);
+			if (pPreviewIcon != NULL)
+			{
+				*cIconName = _cd_get_icon_path (pPreviewIcon, NULL);
+				//g_print ("got preview icon '%s'\n", *cIconName);
+			}
+		}*/
+		#endif
+		// if no thumbnail available and the file is an image, use it directly.
+		if (*cIconName == NULL && cMimeType != NULL && strncmp (cMimeType, "image", 5) == 0)
 		{
-			g_error_free (erreur);
+			gchar *cHostname = NULL;
+			GError *erreur = NULL;
+			gchar *cFilePath = g_filename_from_uri (cBaseURI, &cHostname, &erreur);
+			if (erreur != NULL)
+			{
+				g_error_free (erreur);
+			}
+			else if (cHostname == NULL || strcmp (cHostname, "localhost") == 0)  // on ne recupere la vignette que sur les fichiers locaux.
+			{
+				*cIconName = g_strdup (cFilePath);
+				cairo_dock_remove_html_spaces (*cIconName);
+			}
+			g_free (cHostname);
 		}
-		else if (cHostname == NULL || strcmp (cHostname, "localhost") == 0)  // on ne recupere la vignette que sur les fichiers locaux.
+		// else, get the icon for the mime-types.
+		if (*cIconName == NULL)
 		{
-			*cIconName = g_strdup (cFilePath);
-			cairo_dock_remove_html_spaces (*cIconName);
+			GIcon *pSystemIcon = g_file_info_get_icon (pFileInfo);
+			if (pSystemIcon != NULL)
+			{
+				*cIconName = _cd_get_icon_path (pSystemIcon, cTargetURI ? cTargetURI : *cURI);
+			}
 		}
-		//g_free (cHostname);
+		cd_message ("cIconName : %s", *cIconName);
 	}
-	if (*cIconName == NULL)
-	{
-		GIcon *pSystemIcon = g_file_info_get_icon (pFileInfo);
-		if (pSystemIcon != NULL)
-		{
-			*cIconName = _cd_get_icon_path (pSystemIcon, cTargetURI ? cTargetURI : *cURI);
-		}
-	}
-	cd_message ("cIconName : %s", *cIconName);
 	
-	//*iVolumeID = g_file_info_get_attribute_uint32 (pFileInfo, G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE);
-	//cd_message ("ID : %d\n", *iVolumeID);
 	g_object_unref (pFileInfo);
+	g_object_unref (pFile);
 }
 
 static Icon *_cd_get_icon_for_volume (GVolume *pVolume, GMount *pMount)
@@ -698,7 +737,7 @@ static GList *cairo_dock_gio_vfs_list_directory (const gchar *cBaseURI, CairoDoc
 		&erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome_integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_error_free (erreur);
 		g_object_unref (pFile);
 		return NULL;
@@ -714,7 +753,7 @@ static GList *cairo_dock_gio_vfs_list_directory (const gchar *cBaseURI, CairoDoc
 		pFileInfo = g_file_enumerator_next_file (pFileEnum, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			erreur = NULL;
 			continue;
@@ -888,12 +927,12 @@ static GList *cairo_dock_gio_vfs_list_directory (const gchar *cBaseURI, CairoDoc
 		
 		icon = cairo_dock_create_dummy_launcher (g_strdup ("home"),
 			g_strdup (pRootIcon->cFileName),
-			g_strdup ("/home"),
+			g_strdup (g_getenv ("HOME")),
 			NULL,
 			iOrder++);
 		icon->iTrueType = CAIRO_DOCK_ICON_TYPE_FILE;
 		icon->iGroup = iNewIconsGroup;
-		icon->cBaseURI = g_strdup_printf ("file://%s", "/home");
+		icon->cBaseURI = g_strdup_printf ("file://%s", g_getenv ("HOME"));
 		icon->iVolumeID = 0;
 		
 		pIconList = g_list_insert_sorted (pIconList,
@@ -929,7 +968,7 @@ static gsize cairo_dock_gio_vfs_measure_directory (const gchar *cBaseURI, gint i
 		&erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome_integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_error_free (erreur);
 		g_object_unref (pFile);
 		return 0;
@@ -943,7 +982,7 @@ static gsize cairo_dock_gio_vfs_measure_directory (const gchar *cBaseURI, gint i
 		pFileInfo = g_file_enumerator_next_file (pFileEnum, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			erreur = NULL;
 			continue;
@@ -1014,21 +1053,65 @@ static gchar *_cd_find_target_uri (const gchar *cBaseURI)
 static void cairo_dock_gio_vfs_launch_uri (const gchar *cURI)
 {
 	g_return_if_fail (cURI != NULL);
+	
+	// in case it's a mount point, take the URI that can actually be launched. 
 	GError *erreur = NULL;
 	gchar *cValidUri = (*cURI == '/' ? g_strconcat ("file://", cURI, NULL) : g_strdup (cURI));
 	cd_message ("%s (%s)", __func__, cValidUri);
 	
 	gchar *cTargetURI = _cd_find_target_uri (cValidUri);
-	gboolean bSuccess = g_app_info_launch_default_for_uri (cTargetURI != NULL ? cTargetURI : cValidUri,
+	cURI= (cTargetURI ? cTargetURI : cValidUri);
+	
+	// now, try to launch it with the default program know by gvfs.
+	gboolean bSuccess = g_app_info_launch_default_for_uri (cURI,
 		NULL,
 		&erreur);
+	if (erreur != NULL)  // error can happen (for instance, opening 'trash:/' on XFCE with a previous installation of nautilus) => try with another method.
+	{
+		cd_debug ("gvfs-integration : couldn't launch '%s' [%s]", cURI, erreur->message);
+		g_error_free (erreur);
+		erreur = NULL;
+		
+		// get the mime-type.
+		GFile *pFile = (*cURI == '/' ? g_file_new_for_path (cURI) : g_file_new_for_uri (cURI));
+		const gchar *cQuery = G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE;
+		GFileInfo *pFileInfo = g_file_query_info (pFile,
+			cQuery,
+			G_FILE_QUERY_INFO_NONE,
+			NULL,
+			&erreur);
+		if (erreur != NULL)  // if no mime-type (can happen with not mounted volumes), abort.
+		{
+			cd_warning ("gvfs-integration : %s", erreur->message);
+			g_error_free (erreur);
+		}
+		else
+		{
+			// get all the apps that can launch it.
+			const gchar *cMimeType = g_file_info_get_content_type (pFileInfo);
+			GList *pAppsList = g_app_info_get_all_for_type (cMimeType);
+			gchar *cCommand;
+			GAppInfo *pAppInfo;
+			const char *cExec;
+			GList *a;
+			for (a = pAppsList; a != NULL; a = a->next)
+			{
+				pAppInfo = a->data;
+				cExec = g_app_info_get_executable (pAppInfo);
+				if (cExec)  // use the first available. it is supposed to be the most suitable, but the default method doesn't seem to use it.
+				{
+					gchar *cPath = g_filename_from_uri (cURI, NULL, NULL);
+					cairo_dock_launch_command_printf ("%s \"%s\"", NULL, cExec, cPath?cPath:cURI);  // in case the program doesn't handle URI (geeqie, etc).
+					g_free (cPath);
+					break;
+				}
+			}
+			g_list_free (pAppsList);
+		}
+		g_object_unref (pFile);
+	}
 	g_free (cValidUri);
 	g_free (cTargetURI);
-	if (erreur != NULL)
-	{
-		cd_warning ("gnome_integration : couldn't launch '%s' [%s]", cURI, erreur->message);
-		g_error_free (erreur);
-	}
 }
 
 static GMount *_cd_find_mount_from_uri (const gchar *cURI, gchar **cTargetURI)
@@ -1143,7 +1226,7 @@ static void _gio_vfs_mount_callback (gpointer pObject, GAsyncResult *res, gpoint
 		bSuccess = g_mount_eject_finish (G_MOUNT (pObject), res, &erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome-integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_error_free (erreur);
 	}
 	
@@ -1298,7 +1381,7 @@ static void cairo_dock_gio_vfs_add_monitor (const gchar *cURI, gboolean bDirecto
 	//g_object_unref (pFile);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome-integration : couldn't add monitor on '%s' (%d) [%s]", cURI, bDirectory, erreur->message);
+		cd_warning ("gvfs-integration : couldn't add monitor on '%s' (%d) [%s]", cURI, bDirectory, erreur->message);
 		g_error_free (erreur);
 		return ;
 	}
@@ -1341,7 +1424,7 @@ static gboolean cairo_dock_gio_vfs_delete_file (const gchar *cURI, gboolean bNoT
 			&erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			g_object_unref (pFile);
 			return FALSE;
@@ -1356,7 +1439,7 @@ static gboolean cairo_dock_gio_vfs_delete_file (const gchar *cURI, gboolean bNoT
 		bSuccess = g_file_delete (pFile, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome-integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 		}
 	}
@@ -1365,7 +1448,7 @@ static gboolean cairo_dock_gio_vfs_delete_file (const gchar *cURI, gboolean bNoT
 		bSuccess = g_file_trash (pFile, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome-integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 		}
 	}
@@ -1381,7 +1464,7 @@ static gboolean cairo_dock_gio_vfs_rename_file (const gchar *cOldURI, const gcha
 	GFile *pNewFile = g_file_set_display_name (pOldFile, cNewName, NULL, &erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome-integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_error_free (erreur);
 	}
 	gboolean bSuccess = (pNewFile != NULL);
@@ -1413,7 +1496,7 @@ static gboolean cairo_dock_gio_vfs_move_file (const gchar *cURI, const gchar *cD
 		&erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome-integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_error_free (erreur);
 	}
 	g_object_unref (pFile);
@@ -1436,7 +1519,7 @@ static gboolean cairo_dock_gio_vfs_create_file (const gchar *cURI, gboolean bDir
 		g_file_create (pFile, G_FILE_CREATE_PRIVATE, NULL, &erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome-integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_error_free (erreur);
 		bSuccess = FALSE;
 	}
@@ -1465,7 +1548,7 @@ static void cairo_dock_gio_vfs_get_file_properties (const gchar *cURI, guint64 *
 		&erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome-integration : couldn't get file properties for '%s' [%s]", cURI, erreur->message);
+		cd_warning ("gvfs-integration : couldn't get file properties for '%s' [%s]", cURI, erreur->message);
 		g_error_free (erreur);
 	}
 	
@@ -1532,7 +1615,7 @@ static void _cairo_dock_gio_vfs_empty_dir (const gchar *cBaseURI)
 		&erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome_integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_object_unref (pFile);
 		g_error_free (erreur);
 		return ;
@@ -1546,7 +1629,7 @@ static void _cairo_dock_gio_vfs_empty_dir (const gchar *cBaseURI)
 		pFileInfo = g_file_enumerator_next_file (pFileEnum, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			erreur = NULL;
 			continue;
@@ -1567,7 +1650,7 @@ static void _cairo_dock_gio_vfs_empty_dir (const gchar *cBaseURI)
 		g_file_delete (file, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			erreur = NULL;
 		}
@@ -1604,7 +1687,7 @@ static void cairo_dock_gio_vfs_empty_trash (void)
 		&erreur);
 	if (erreur != NULL)
 	{
-		cd_warning ("gnome_integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_object_unref (pFile);
 		g_error_free (erreur);
 		return ;
@@ -1618,7 +1701,7 @@ static void cairo_dock_gio_vfs_empty_trash (void)
 		pFileInfo = g_file_enumerator_next_file (pFileEnum, NULL, &erreur);
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			erreur = NULL;
 			continue;
@@ -1681,7 +1764,7 @@ static void cairo_dock_gio_vfs_empty_trash (void)
 		}
 		if (erreur != NULL)
 		{
-			cd_warning ("gnome_integration : %s", erreur->message);
+			cd_warning ("gvfs-integration : %s", erreur->message);
 			g_error_free (erreur);
 			erreur = NULL;
 		}
@@ -1713,7 +1796,7 @@ static GList *cairo_dock_gio_vfs_list_apps_for_file (const gchar *cBaseURI)
 	
 	if (erreur != NULL)  // peut arriver si l'emplacement n'est pas monte, mais on signale tout de meme la raison avec un warning.
 	{
-		cd_warning ("gnome_integration : %s", erreur->message);
+		cd_warning ("gvfs-integration : %s", erreur->message);
 		g_error_free (erreur);
 		g_free (cValidUri);
 		g_object_unref (pFile);
