@@ -29,8 +29,8 @@
 CD_APPLET_DEFINE_BEGIN ("xfce integration",
 	1, 6, 2,
 	CAIRO_DOCK_CATEGORY_APPLET_SYSTEM,
-	N_("This applet provides functions for a better integration into a XFCE environnement.\n"
-	"It is auto-activated, so you don't need to activate it."),
+	"This applet provides functions for a better integration into a XFCE environnement.\n"
+	"It is auto-activated, so you don't need to activate it.",
 	"Tofe (Christophe Chapuis")
 	if (g_iDesktopEnv == CAIRO_DOCK_XFCE)
 	{
@@ -61,7 +61,7 @@ CD_APPLET_DEFINE_BEGIN ("xfce integration",
 			pVFSBackend->get_desktop_path = vfs_backend_get_desktop_path;
 		}
 #endif
-		if(NULL != pVFSBackend)
+		if(pVFSBackend != NULL)
 		{
 			pVFSBackend->logout = env_backend_logout;
 			pVFSBackend->shutdown = env_backend_shutdown;
